@@ -317,14 +317,40 @@ class VulnerabilityRelatedReference(models.Model):
         ordering = ["vulnerability", "reference"]
 
 
+def purl_to_dict(purl: PackageURL):
+    """
+    Return a dict of purl components suitable for use in a queryset.
+    We need to have specific empty values for using in querysets because of our peculiar model structure.
+
+    For example::
+    >>> purl_to_dict(PackageURL.from_string("pkg:generic/postgres"))
+    {'type': 'generic', 'namespace': '', 'name': 'postgres', 'version': '', 'qualifiers': {}, 'subpath': ''}
+    >>> purl_to_dict(PackageURL.from_string("pkg:generic/postgres/postgres@1.2?foo=bar#baz"))
+    {'type': 'generic', 'namespace': 'postgres', 'name': 'postgres', 'version': '1.2', 'qualifiers': {'foo': 'bar'}, 'subpath': 'baz'}
+    """
+    if isinstance(purl, str):
+        purl = PackageURL.from_string(purl)
+
+    return dict(
+        type=purl.type,
+        namespace=purl.namespace or "",
+        name=purl.name,
+        version=purl.version or "",
+        qualifiers=purl.qualifiers or {},
+        subpath=purl.subpath or "",
+    )
+
+
 class PackageQuerySet(BaseQuerySet, PackageURLQuerySet):
     def get_or_create_from_purl(self, purl: PackageURL):
         """
         Return an existing or new Package (created if neeed) given a
         ``purl`` PackageURL.
         """
-        purl_fields = without_empty_values(purl.to_dict(encode=True))
-        package, _ = Package.objects.get_or_create(**purl_fields)
+        if isinstance(purl, str):
+            purl = PackageURL.from_string(purl)
+
+        package, _ = Package.objects.get_or_create(**purl_to_dict(purl=purl))
         return package
 
     def for_package_url_object(self, purl):
@@ -333,15 +359,12 @@ class PackageQuerySet(BaseQuerySet, PackageURLQuerySet):
         ``purl`` string is validated and transformed into filtering lookups. If
         this is a PackageURL object it is reused as-is.
         """
-        if isinstance(purl, PackageURL):
-            lookups = without_empty_values(purl.to_dict(encode=True))
-            return self.filter(**lookups)
-
-        elif isinstance(purl, str):
-            return self.for_package_url(purl, encode=False)
-
-        else:
+        if not purl:
             return self.none()
+        if isinstance(purl, str):
+            purl = PackageURL.from_string(purl)
+        lookups = without_empty_values(purl.to_dict(encode=True))
+        return self.filter(**lookups)
 
     def affected(self):
         """
@@ -389,53 +412,14 @@ class PackageQuerySet(BaseQuerySet, PackageURLQuerySet):
         query = query and query.strip()
         if not query:
             return self.none()
-
         qs = self
-        if not query.startswith("pkg:"):
-            # treat this as a plain search
-            qs = qs.filter(Q(name__icontains=query) | Q(namespace__icontains=query))
-        else:
-            # this looks like a purl: check if it quacks like a purl
-            purl_type = namespace = name = version = None
 
-            _, _scheme, remainder = query.partition("pkg:")
-            remainder = remainder.strip()
-            if not remainder:
-                return qs.none()
-
-            try:
-                # First, treat the query as a syntactically-correct purl
-                purl = PackageURL.from_string(query)
-                purl_type, namespace, name, version, _quals, _subp = purl.to_dict().values()
-            except ValueError:
-                # Otherwise, attempt a more lenient parsing of a possibly partial purl
-                if "/" in remainder:
-                    purl_type, _scheme, ns_name = remainder.partition("/")
-                    ns_name = ns_name.strip()
-                    if ns_name:
-                        if "/" in ns_name:
-                            namespace, _, name = ns_name.partition("/")
-                        else:
-                            name = ns_name
-                        name = name.strip()
-                        if name:
-                            if "@" in name:
-                                name, _, version = name.partition("@")
-                                version = version.strip()
-                                name = name.strip()
-                else:
-                    purl_type = remainder
-
-            if purl_type:
-                qs = qs.filter(type__iexact=purl_type)
-            if namespace:
-                qs = qs.filter(namespace__iexact=namespace)
-            if name:
-                qs = qs.filter(name__iexact=name)
-            if version:
-                qs = qs.filter(version__iexact=version)
-
-        return qs
+        try:
+            # if it's a valid purl, use it as is
+            purl = PackageURL.from_string(query)
+            return self.for_purl(purl, with_qualifiers_and_subpath=False)
+        except ValueError:
+            return qs.filter(package_url__icontains=query)
 
     def for_purl(self, purl, with_qualifiers_and_subpath=True):
         """
@@ -443,7 +427,7 @@ class PackageQuerySet(BaseQuerySet, PackageURLQuerySet):
         """
         if not isinstance(purl, PackageURL):
             purl = PackageURL.from_string(purl)
-        purl = purl.to_dict()
+        purl = purl_to_dict(purl)
         if not with_qualifiers_and_subpath:
             del purl["qualifiers"]
             del purl["subpath"]
@@ -508,8 +492,41 @@ class Package(PackageURLMixin):
         to="Vulnerability", through="PackageRelatedVulnerability"
     )
 
+    package_url = models.CharField(
+        max_length=1000,
+        null=False,
+        help_text="The Package URL for this package.",
+        db_index=True,
+    )
+
+    plain_package_url = models.CharField(
+        max_length=1000,
+        null=False,
+        help_text="The Package URL for this package without qualifiers and subpath.",
+        db_index=True,
+    )
+
     objects = PackageQuerySet.as_manager()
 
+    def save(self, *args, **kwargs):
+        purl_object = PackageURL(
+            type=self.type,
+            namespace=self.namespace,
+            name=self.name,
+            version=self.version,
+            qualifiers=self.qualifiers,
+            subpath=self.subpath,
+        )
+        plain_purl = PackageURL(
+            type=self.type,
+            namespace=self.namespace,
+            name=self.name,
+            version=self.version,
+        )
+        self.package_url = str(purl_object)
+        self.plain_package_url = str(plain_purl)
+        super().save(*args, **kwargs)
+
     @property
     def purl(self):
         return self.package_url
@@ -661,6 +678,13 @@ class VulnerabilitySeverity(models.Model):
 
     value = models.CharField(max_length=50, help_text="Example: 9.0, Important, High")
 
+    scoring_elements = models.CharField(
+        max_length=150,
+        null=True,
+        help_text="Supporting scoring elements used to compute the score values. "
+        "For example a CVSS vector string as used to compute a CVSS score.",
+    )
+
     class Meta:
         unique_together = ["reference", "scoring_system", "value"]
         ordering = ["reference", "scoring_system", "value"]
@@ -718,6 +742,10 @@ class Alias(models.Model):
         if alias.startswith("GHSA"):
             return f"https://github.com/advisories/{alias}"
 
+        if alias.startswith("NPM-"):
+            id = alias.lstrip("NPM-")
+            return f"https://github.com/nodejs/security-wg/blob/main/vuln/npm/{id}.json"
+
 
 class Advisory(models.Model):
     """
