@@ -31,15 +31,11 @@ collect_ignore = [
     "test_api.py",
     "test_elixir_security.py",
     "test_gentoo.py",
-    "test_importer_yielder.py",
     "test_istio.py",
     "test_models.py",
     "test_mozilla.py",
     "test_msr2019.py",
-    "test_npm.py",
     "test_package_managers.py",
-    "test_postgresql.py",
-    "test_retiredotnet.py",
     "test_ruby.py",
     "test_rust.py",
     "test_safety_db.py",
